@@ -4,7 +4,7 @@ use strict;
 use utf8;
 require Text::Metaphone::Amharic;
 
-my $am = new Text::Metaphone::Amharic ( grandularity => "high" );
+my $am = new Text::Metaphone::Amharic ( granularity => "high" );
 
 my @keys  = $am->metaphone ( "ኘሬዚደንት" );
 my $count = 0;
@@ -38,7 +38,7 @@ __END__
 
 =head1 NAME
 
-amphone-high.pl - Amharic Metaphone demonstrator for 5 sample words (High Grandularity Usage).
+amphone-high.pl - Amharic Metaphone demonstrator for 5 sample words (High Granularity Usage).
 
 =head1 SYNOPSIS
 
@@ -47,7 +47,7 @@ amphone-high.pl - Amharic Metaphone demonstrator for 5 sample words (High Grandu
 =head1 DESCRIPTION
 
 This is a simple demonstration script that generates Amharic Metaphone
-keys in Ethiopic script under the "high" grandularity setting.
+keys in Ethiopic script under the "high" granularity setting.
 
 =head1 AUTHOR
 
